@@ -21,7 +21,7 @@ def init_cli() -> argparse.ArgumentParser:
     """Initialize the argument parser to handle the command line interface."""
 
     cli: argparse.ArgumentParser = argparse.ArgumentParser(
-        usage="%(prog)s (<robots_path>|<robots_url>) <user_agent> <URI>",
+        usage="%(prog)s <robotstxt> <useragent> <path>",
         description=(
             "Shows whether the given user agent and URI combination "
             "are allowed or disallowed by the given robots.txt file."
@@ -33,7 +33,7 @@ def init_cli() -> argparse.ArgumentParser:
     )
     cli.add_argument("robotstxt", help="robots.txt file path or URL")
     cli.add_argument("useragent", help="User agent name")
-    cli.add_argument("uri", help="Path or URI")
+    cli.add_argument("path", help="Path or URL")
 
     return cli
 
@@ -70,10 +70,11 @@ def main() -> None:
     robots_uri = normalize_uri(args.robotstxt)
     robots_parser = create_robots(robots_uri)
 
-    allowed = robots_parser.can_fetch(args.useragent, args.uri)
+    allowed = robots_parser.can_fetch(args.useragent, args.path)
 
     allowed_str = "ALLOWED" if allowed else "DISALLOWED"
-    print(f"user-agent '{args.useragent}' with URI '{args.uri}': {allowed_str}")
+    url_or_path = "url" if is_url(args.path) else "path"
+    print(f"user-agent '{args.useragent}' with {url_or_path} '{args.path}': {allowed_str}")
 
     if errors := robots_parser.errors:
         for error in errors:
